
From: Giancarlo Formicuccia <giancarlo.formicuccia@gmail.com>

This patch:
http://marc.theaimsgroup.com/?l=bk-commits-head&m=111955644929114&w=2
uncovered a k7m bios bug, where the VT82C686A router is reported as
being "586-compatible". The two chips have different pirq mapping, so
this leads to "irq routing conflict" on many pci devices.

The suggested fix was discussed with Aleksey Gorelov, who helped me
to identify the problem as a probable bios bug.

Signed-off-by: Giancarlo Formicuccia <giancarlo.formicuccia@gmail.com>
Cc: Dave Jones <davej@codemonkey.org.uk>
Cc: Greg KH <greg@kroah.com>
Signed-off-by: Andrew Morton <akpm@osdl.org>
---

 arch/i386/pci/irq.c |    7 +++++++
 1 files changed, 7 insertions(+)

diff -puN arch/i386/pci/irq.c~fix-incorrect-asus-k7m-irq-router-detection arch/i386/pci/irq.c
--- devel/arch/i386/pci/irq.c~fix-incorrect-asus-k7m-irq-router-detection	2005-07-28 01:05:53.000000000 -0700
+++ devel-akpm/arch/i386/pci/irq.c	2005-07-28 01:05:53.000000000 -0700
@@ -550,6 +550,13 @@ static __init int intel_router_probe(str
 static __init int via_router_probe(struct irq_router *r, struct pci_dev *router, u16 device)
 {
 	/* FIXME: We should move some of the quirk fixup stuff here */
+
+	if (router->device == PCI_DEVICE_ID_VIA_82C686 &&
+			device == PCI_DEVICE_ID_VIA_82C586_0) {
+		/* Asus k7m bios wrongly reports 82C686A as 586-compatible */
+		device = PCI_DEVICE_ID_VIA_82C686;
+	}
+
 	switch(device)
 	{
 		case PCI_DEVICE_ID_VIA_82C586_0:
_
